@@ -24,10 +24,12 @@
 # *
 # **************************************************************************
 
-from pyworkflow.utils import magentaStr, join, makePath, copyFile
+import os
+
+from pyworkflow.utils import magentaStr, makePath, copyFile
 from pyworkflow.tests import BaseTest, DataSet, setupTestProject
 from pyworkflow.plugin import Domain
-import pwem
+from pwem.objects import Volume
 from pwem.protocols import ProtImportParticles, ProtImportVolumes
 
 from ..protocols import ProtSideSplitter
@@ -50,9 +52,9 @@ class TestSideSplitter(BaseTest):
         setupTestProject(cls)
         cls.ds = DataSet.getDataSet('relion_tutorial')
         pathFns = 'import/refine3d/extra'
-        cls.volFn = cls.ds.getFile(join(pathFns, 'relion_class001.mrc'))
-        cls.half1Fn = cls.ds.getFile(join(pathFns, 'relion_it025_half1_class001.mrc'))
-        cls.half2Fn = cls.ds.getFile(join(pathFns, 'relion_it025_half2_class001.mrc'))
+        cls.volFn = cls.ds.getFile(os.path.join(pathFns, 'relion_class001.mrc'))
+        cls.half1Fn = cls.ds.getFile(os.path.join(pathFns, 'relion_it025_half1_class001.mrc'))
+        cls.half2Fn = cls.ds.getFile(os.path.join(pathFns, 'relion_it025_half2_class001.mrc'))
 
     def importVolume(self):
         print(magentaStr("\n==> Importing data - volume:"))
@@ -93,7 +95,7 @@ class TestSideSplitter(BaseTest):
         outputVol = self.importVolume().outputVolume
         prot.referenceVolume.set(outputVol)
 
-        volume = pwem.objects.Volume()
+        volume = Volume()
         volume.setFileName(prot._getExtraPath('test.mrc'))
         pxSize = prot.inputParticles.get().getSamplingRate()
         volume.setSamplingRate(pxSize)
